==> peerplays-0.1.0-py3-none-any.whl: peerplays/witness.py <==
from peerplays.instance import shared_peerplays_instance
from .account import Account
from .exceptions import WitnessDoesNotExistsException


class Witness(dict):
    """ Read data about a witness in the chain

        :param str account_name: Name of the witness
        :param peerplays peerplays_instance: PeerPlays() instance to use when accesing a RPC

    """

    witness_cache = dict()

    def __init__(
        self,
        witness,
        lazy=False,
        peerplays_instance=None,
    ):
        self.peerplays = peerplays_instance or shared_peerplays_instance()
        self.cached = False

        if isinstance(witness, Witness):
            self.witness = witness["name"]
            super(Witness, self).__init__(witness)
            self.cached = True
            self._cache(witness)
        else:
            self.witness = witness
            if witness in Witness.witness_cache:
                super(Witness, self).__init__(Witness.witness_cache[witness])
                self.cached = True
            elif not lazy and not self.cached:
                self.refresh()

    def _cache(self, witness):
        # store in cache
        Witness.witness_cache[witness["id"]] = witness

    def refresh(self):
        parts = self.witness.split(".")
        if len(parts) == 3:
            a, b, _ = self.witness.split(".")
            assert int(a) == 1 and (int(b) == 6 or int(b) == 2), "Witness id's need to be 1.6.x or 1.2.x!"
            if int(b) == 6:
                witness = self.peerplays.rpc.get_object(self.witness)
            else:
                witness = self.peerplays.rpc.get_witness_by_account(self.witness)
        else:
            account = Account(self.witness)
            witness = self.peerplays.rpc.get_witness_by_account(account["id"])
        if not witness:
            raise WitnessDoesNotExistsException
        super(Witness, self).__init__(witness)
        self._cache(witness)

    def __getitem__(self, key):
        if not self.cached:
            self.refresh()
        return super(Witness, self).__getitem__(key)

    def items(self):
        if not self.cached:
            self.refresh()
        return super(Witness, self).items()

    @property
    def account(self):
        return Account(self["witness_account"])

    def __repr__(self):
        return "<Witness %s>" % str(self.witness)


class Witnesses(list):
    """ Obtain a list of **active** witnesses and the current schedule

        :param peerplays peerplays_instance: PeerPlays() instance to use when accesing a RPC
    """
    def __init__(self, peerplays_instance=None):
        self.peerplays = peerplays_instance or shared_peerplays_instance()
        self.schedule = self.peerplays.rpc.get_object("2.12.0").get("current_shuffled_witnesses", [])

        super(Witnesses, self).__init__(
            [
                Witness(x, lazy=True, peerplays_instance=self.peerplays)
                for x in self.schedule
            ]
        )

==> peerplays-0.1.3-py3-none-any.whl: peerplays/witness.py <==
from peerplays.instance import shared_peerplays_instance
from .account import Account
from .exceptions import WitnessDoesNotExistsException
from .blockchainobject import BlockchainObject


class Witness(BlockchainObject):
    """ Read data about a witness in the chain

        :param str account_name: Name of the witness
        :param peerplays peerplays_instance: PeerPlays() instance to use when accesing a RPC

    """

    type_ids = [6, 2]

    def refresh(self):
        parts = self.identifier.split(".")
        if int(parts[1]) == 6:
            witness = self.peerplays.rpc.get_object(self.identifier)
        else:
            witness = self.peerplays.rpc.get_witness_by_account(self.identifier)
        if not witness:
            raise WitnessDoesNotExistsException
        super(Witness, self).__init__(witness)

    @property
    def account(self):
        return Account(self["witness_account"])


class Witnesses(list):
    """ Obtain a list of **active** witnesses and the current schedule

        :param peerplays peerplays_instance: PeerPlays() instance to use when accesing a RPC
    """
    def __init__(self, peerplays_instance=None):
        self.peerplays = peerplays_instance or shared_peerplays_instance()
        self.schedule = self.peerplays.rpc.get_object("2.12.0").get("current_shuffled_witnesses", [])

        super(Witnesses, self).__init__(
            [
                Witness(x, lazy=True, peerplays_instance=self.peerplays)
                for x in self.schedule
            ]
        )
